@@ -31,14 +31,14 @@ def mkr(path):
         os.makedirs(path, exist_ok=True)
 
 
-def get_CK5(origin_base_dir, output_voc_dir, data_types=None):
-    if data_types is None:
-        data_types = ["train"]
+def get_CK5(origin_base_dir, output_voc_dir):
+    # if data_types is None:
+    #     data_types = ["train"]
 
     origin_anno_dir = os.path.join(origin_base_dir, 'Annotations')  # 原始的coco的标注存放位置
-    # dataTypes = ['train']
+    data_types = ['train']
     for dataType in data_types:
-        origin_Images_dir = os.path.join(origin_base_dir, 'Images', dataType)
+        origin_Images_dir = os.path.join(origin_base_dir, dataType)
 
         dst_ImageSets_txt_dir = os.path.join(output_voc_dir, 'ImageSets', 'Main')  # VOC ImageSets
         dst_Annotations_dir = os.path.join(output_voc_dir, 'Annotations')  # VOC Annotations
@@ -120,23 +120,23 @@ def get_args():
                         default='C:/Users/xgy/Desktop/voc_coco/cocotest')
     parser.add_argument("--output_voc_dir", help="Directory path to voc.", type=str,
                         default='C:/Users/xgy/Desktop/voc_coco/voctest')
-    parser.add_argument("--data_types", help="待转换的coco的数据集列表.", type=list,
-                        default=['train'])  # 'train1','train2','val1',
+    # parser.add_argument("--data_types", help="待转换的coco的数据集列表.", type=list,
+    #                     default=['train'])  # 'train1','train2','val1',
     args = parser.parse_args()
 
     return args
 
 
-def main(origin_base_dir, output_voc_dir, data_types=None):
-    if data_types is None:
-        data_types = ["train"]
+def main(origin_base_dir, output_voc_dir):
+    assert origin_base_dir != output_voc_dir, "the output voc folder should be different from the original coco folder"
 
     mkr(output_voc_dir)
-    get_CK5(origin_base_dir, output_voc_dir, data_types)
+    # get_CK5(origin_base_dir, output_voc_dir, data_types)
+    get_CK5(origin_base_dir, output_voc_dir)
     logger.info('voc_dir: {}'.format(output_voc_dir))
 
 
 if __name__ == "__main__":
     args = get_args()
-    main(args.origin_base_dir, args.output_voc_dir, args.data_types)
+    main(args.origin_base_dir, args.output_voc_dir)
 
