@@ -114,7 +114,9 @@ def convert(xml_files, json_path):
                 json_dict["annotations"].append(ann)
                 bnd_id = bnd_id + 1
             except:
-                print(xml_file) 
+                print(xml_file)
+                logger.error("some errors hanppend in xmin, xmax, ymin, ymax: {} {} {} {}".format(xmin, xmax, ymin, ymax))
+                # print("xmin, xmax, ymin, ymax: {} {} {} {}".format(xmin, xmax, ymin, ymax))
 
     for cate, cid in categories.items():
         cat = {"supercategory": "", "id": cid, "name": cate}
@@ -132,7 +134,7 @@ def read_txt(filename):
         return f.readlines()
 
 
-def drop_imageset(folder):
+def drop_imageset(folder, xml_folder):
     """
     # 判断是否有 ImageSets/Main/ 文件夹
     # 平台导出数据集有，标准voc没有，需分别处理
@@ -146,13 +148,17 @@ def drop_imageset(folder):
     data_types = []
     if not os.path.exists(folder):
         os.makedirs(folder)
-        for root, _, files in os.walk(folder):
-            for xml_item in files:
-                xml_name = os.path.splitext(xml_item)[0]
-                trainval_path = os.path.join(folder, "trainval.txt")
-                with open(trainval_path, "a+", encoding="utf-8") as fw:
-                    fw.write(xml_name)
-                    fw.write("\n")
+    trainval_path = os.path.join(folder, "trainval.txt")
+
+    for root, _, files in os.walk(xml_folder):
+        for xml_item in files:
+            if not xml_item.endswith(".xml"):
+                continue
+            xml_name = os.path.splitext(xml_item)[0]
+
+            with open(trainval_path, "a+", encoding="utf-8") as fw:
+                fw.write(xml_name)
+                fw.write("\n")
 
     for root, _, files in os.walk(folder):
         num_txt = len(files)
@@ -179,7 +185,7 @@ def main(voc_dir, out_coco_path):
     voc_img_dir = os.path.join(voc_dir, 'JPEGImages')
     voc_txt_dir = os.path.join(voc_dir, 'ImageSets', 'Main')
 
-    data_types = drop_imageset(voc_txt_dir)
+    data_types = drop_imageset(voc_txt_dir, voc_xml_dir)
     # if data_types is None:
     #     data_types = ["trainval"]
 
@@ -214,5 +220,8 @@ def main(voc_dir, out_coco_path):
 
 if __name__ == "__main__":
     args = get_args()
-    # main(args.voc_dir, args.out_coco_path, args.data_types)
     main(args.voc_dir, args.out_coco_path)
+
+    # voc_dir = "C:/Users/xgy/Desktop/eva_scene/eva"
+    # out_coco_path = "C:/Users/xgy/Desktop/eva_scene/eva_test_coco"
+    # main(voc_dir, out_coco_path)
