@@ -27,6 +27,7 @@ def get_and_check(root, name, length):
         vars = vars[0]
     return vars
 
+
 tree = ET.parse(xml_path)
 root = tree.getroot()
 # for member in root.findall("size"):
@@ -36,12 +37,12 @@ root = tree.getroot()
 # size = get_and_check(root, "size", 1)
 # width = int(get_and_check(size, "width", 1).text)
 # width = int(root.find("size").find("width").text)
-
-for obj in root.findall("object"):
-    # try:
-    bndbox = obj.find("bndbox")
-    xmin = int(bndbox.find("xmin").text) - 1
-    print(xmin)
+#
+# for obj in root.findall("object"):
+#     # try:
+#     bndbox = obj.find("bndbox")
+#     xmin = int(bndbox.find("xmin").text) - 1
+#     print(xmin)
 
 if __name__ == '__main__':
     print("start")
